searchData={"items":[{"type":"module","title":"Extep","doc":"A tiny and friendly step runner for Elixir pipelines.\n\nExtep is a simple and dependency-free utility that helps you compose Elixir pipelines using a shared context.\nIt's useful for building multi-step workflows that can gracefully **halt** or **error** along the way.\nExtep is an implementation of the Railway-oriented programming and was inspired by\n[Ecto.Multi](https://hexdocs.pm/ecto/Ecto.Multi.html) and [Sage](https://hexdocs.pm/sage/readme.html).","ref":"Extep.html"},{"type":"module","title":"Example - Extep","doc":"iex> params = %{user_id: 1, plan: \"super-power-plus\"}\n    iex> Extep.new(%{params: params})\n    ...> |> Extep.run(:params, &validate_params/1)\n    ...> |> Extep.run(:user, &fetch_user/1)\n    ...> |> Extep.run(:items, &fetch_items/1)\n    ...> |> Extep.return(&create_subscription/1)\n    {:ok, %{id: 123, object: \"subscription\", user_id: 1, items: [%{code: \"item1\"}, %{code: \"item2\"}]}}","ref":"Extep.html#module-example"},{"type":"type","title":"Extep.context/0","doc":"","ref":"Extep.html#t:context/0"},{"type":"type","title":"Extep.context_checker_fun/0","doc":"","ref":"Extep.html#t:context_checker_fun/0"},{"type":"type","title":"Extep.context_key/0","doc":"","ref":"Extep.html#t:context_key/0"},{"type":"type","title":"Extep.context_mutator_fun/0","doc":"","ref":"Extep.html#t:context_mutator_fun/0"},{"type":"function","title":"Extep.new/0","doc":"Creates a new `Extep` struct with an empty context.","ref":"Extep.html#new/0"},{"type":"function","title":"Examples - Extep.new/0","doc":"iex> Extep.new()\n    %Extep{status: :ok, context: %{}, message: nil}","ref":"Extep.html#new/0-examples"},{"type":"function","title":"Extep.new/1","doc":"Creates a new `Extep` struct with an initial context map.","ref":"Extep.html#new/1"},{"type":"function","title":"Examples - Extep.new/1","doc":"iex> Extep.new(%{foo: \"bar\"})\n    %Extep{status: :ok, context: %{foo: \"bar\"}, message: nil}","ref":"Extep.html#new/1-examples"},{"type":"type","title":"Extep.opts/0","doc":"","ref":"Extep.html#t:opts/0"},{"type":"function","title":"Extep.return/3","doc":"Returns a final result from your pipeline with optional configuration.\n\nThis function extracts the final result from your pipeline based on the pipeline's status:\n\n- **`:ok` status**: Executes the given function or returns the context value for the given key\n- **`:halted` status**: Returns the halt message (ignores all options)\n- **`:error` status**: Returns an error tuple, optionally with or without context labels","ref":"Extep.html#return/3"},{"type":"function","title":"Parameters - Extep.return/3","doc":"- `extep` - The Extep struct containing your pipeline state\n- `fun_or_key` - Either a function `(context -> result)` or an atom key to extract from context\n- `opts` - Keyword list of options (defaults to `[]`)","ref":"Extep.html#return/3-parameters"},{"type":"function","title":"Options - Extep.return/3","doc":"- `label_error` (boolean, default: `false`):\n  - When `false`: Returns clean error messages like `{:error, \"message\"}`\n  - When `true`: Returns labeled errors like `{:error, %{fun_name_or_step_name: \"message\"}}`","ref":"Extep.html#return/3-options"},{"type":"function","title":"Examples - Extep.return/3","doc":"","ref":"Extep.html#return/3-examples"},{"type":"function","title":"Successful Pipeline with Function - Extep.return/3","doc":"When the pipeline succeeds, the function is executed with the context:\n\n    iex> Extep.new(%{foo: 1})\n    ...> |> Extep.run(:bar, fn ctx -> {:ok, ctx.foo + 1} end)\n    ...> |> Extep.return(fn ctx -> {:ok, ctx.bar + 2} end)\n    {:ok, 4}","ref":"Extep.html#return/3-successful-pipeline-with-function"},{"type":"function","title":"Successful Pipeline with Context Key - Extep.return/3","doc":"When the pipeline succeeds, the value for the given key is returned:\n\n    iex> Extep.new(%{foo: 1})\n    ...> |> Extep.run(:bar, fn ctx -> {:ok, ctx.foo + 1} end)\n    ...> |> Extep.run(:baz, fn ctx -> {:ok, ctx.bar + 2} end)\n    ...> |> Extep.return(:bar)\n    {:ok, 2}","ref":"Extep.html#return/3-successful-pipeline-with-context-key"},{"type":"function","title":"Error Pipeline with Default Behavior (Clean Errors) - Extep.return/3","doc":"When the pipeline errors and no options are provided, returns clean error messages:\n\n    iex> Extep.new(%{foo: 1})\n    ...> |> Extep.run(:bar, fn _ctx -> {:error, \"error message\"} end)\n    ...> |> Extep.return(:foo)\n    {:error, \"error message\"}","ref":"Extep.html#return/3-error-pipeline-with-default-behavior-clean-errors"},{"type":"function","title":"Error Pipeline with Function and Labeled Errors - Extep.return/3","doc":"When `label_error: true` is set and a named function causes the error,\nthe error is labeled with the function name:\n\n    iex> Extep.new(%{foo: 1})\n    ...> |> Extep.run(:bar, fn ctx -> {:ok, ctx.foo + 1} end)\n    ...> |> Extep.return(&return_error_tuple/1, label_error: true)\n    {:error, %{return_error_tuple: \"error message\"}}","ref":"Extep.html#return/3-error-pipeline-with-function-and-labeled-errors"},{"type":"function","title":"Error Pipeline with Anonymous Function and Labeled Errors - Extep.return/3","doc":"When `label_error: true` is set and an anonymous function causes the error,\nthe error is labeled with `:no_label`:\n\n    iex> Extep.new(%{foo: 1})\n    ...> |> Extep.run(:bar, fn ctx -> {:ok, ctx.foo + 1} end)\n    ...> |> Extep.return(fn _ctx -> {:error, \"error message\"} end, label_error: true)\n    {:error, %{no_label: \"error message\"}}","ref":"Extep.html#return/3-error-pipeline-with-anonymous-function-and-labeled-errors"},{"type":"function","title":"Error Pipeline with Context Key and Labeled Errors - Extep.return/3","doc":"When `label_error: true` is set and a step with a context key caused the error,\nthe error is labeled with that step's name:\n\n    iex> Extep.new(%{foo: 1})\n    ...> |> Extep.run(:bar, fn _ctx -> {:error, \"error message\"} end)\n    ...> |> Extep.return(:foo, label_error: true)\n    {:error, %{bar: \"error message\"}}","ref":"Extep.html#return/3-error-pipeline-with-context-key-and-labeled-errors"},{"type":"function","title":"Halted Pipeline Returning Function Result - Extep.return/3","doc":"When a function in the pipeline halts with a result, that result is returned directly:\n\n    iex> Extep.new(%{foo: 1})\n    ...> |> Extep.run(:bar, fn ctx -> {:ok, ctx.foo + 1} end)\n    ...> |> Extep.return(fn _ctx -> {:halt, {:ok, \"halt message\"}} end)\n    {:ok, \"halt message\"}","ref":"Extep.html#return/3-halted-pipeline-returning-function-result"},{"type":"function","title":"Halted Pipeline Returning Custom Tuple - Extep.return/3","doc":"Halt messages can be any term, not just ok tuples:\n\n    iex> Extep.new(%{foo: 1})\n    ...> |> Extep.run(:bar, fn ctx -> {:ok, ctx.foo + 1} end)\n    ...> |> Extep.return(fn _ctx -> {:halt, {:cancel, \"cancel message\"}} end)\n    {:cancel, \"cancel message\"}","ref":"Extep.html#return/3-halted-pipeline-returning-custom-tuple"},{"type":"function","title":"Previously Halted Pipeline - Extep.return/3","doc":"When the pipeline was already halted in a previous step, the halt message is returned\nregardless of what you're trying to return:\n\n    iex> Extep.new(%{foo: 1})\n    ...> |> Extep.run(:bar, fn ctx -> {:ok, ctx.foo + 1} end)\n    ...> |> Extep.run(:baz, fn _ctx -> {:halt, {:ok, \"halt message\"}} end)\n    ...> |> Extep.return(:bar)\n    {:ok, \"halt message\"}","ref":"Extep.html#return/3-previously-halted-pipeline"},{"type":"function","title":"Extep.run/2","doc":"Runs a checker function on the context without modifying it.\n\nThis function is useful for validation, checking conditions, or performing side effects\nwithout changing the pipeline context. The context remains unchanged regardless of the\nfunction's return value.","ref":"Extep.html#run/2"},{"type":"function","title":"Function Return Values - Extep.run/2","doc":"The checker function must return one of these values:\n\n- `:ok` - Pipeline continues with unchanged context\n- `{:ok, value}` - Pipeline continues with unchanged context (value is ignored)\n- `{:halt, reason}` - Pipeline stops with `:halted` status, reason stored in message\n- `{:error, reason}` - Pipeline stops with `:error` status, reason stored in message","ref":"Extep.html#run/2-function-return-values"},{"type":"function","title":"Error Message Labeling - Extep.run/2","doc":"When errors occur, the message is stored differently based on the function type:\n\n- **Named functions**: Error labeled with function name (e.g., `%{validate_user: \"error\"}`)\n- **Anonymous functions**: Error labeled with `:no_label` (e.g., `%{no_label: \"error\"}`)","ref":"Extep.html#run/2-error-message-labeling"},{"type":"function","title":"Examples - Extep.run/2","doc":"","ref":"Extep.html#run/2-examples"},{"type":"function","title":"Successful Validation - Simple OK - Extep.run/2","doc":"Basic validation that passes without returning a value:\n\n    iex> Extep.new(%{foo: 1})\n    ...> |> Extep.run(fn _ctx -> :ok end)\n    %Extep{status: :ok, context: %{foo: 1}, message: nil}","ref":"Extep.html#run/2-successful-validation-simple-ok"},{"type":"function","title":"Successful Validation - OK tuple - Extep.run/2","doc":"Validation that passes and returns an ok tuple (value is ignored, context unchanged):\n\n    iex> Extep.new(%{foo: 1})\n    ...> |> Extep.run(fn _ctx -> {:ok, \"is valid\"} end)\n    %Extep{status: :ok, context: %{foo: 1}, message: nil}","ref":"Extep.html#run/2-successful-validation-ok-tuple"},{"type":"function","title":"Error with Named Function - Extep.run/2","doc":"When a named function returns an error tuple, the error is labeled with the function name:\n\n    iex> Extep.new(%{foo: 1})\n    ...> |> Extep.run(&return_error_tuple/1)\n    %Extep{status: :error, context: %{foo: 1}, message: %{return_error_tuple: \"error message\"}}","ref":"Extep.html#run/2-error-with-named-function"},{"type":"function","title":"Error with Anonymous Function - Extep.run/2","doc":"When an anonymous function returns an error tuple, the error is labeled with `:no_label`:\n\n    iex> Extep.new(%{foo: 1})\n    ...> |> Extep.run(fn _ctx -> {:error, \"error message\"} end)\n    %Extep{status: :error, context: %{foo: 1}, message: %{no_label: \"error message\"}}","ref":"Extep.html#run/2-error-with-anonymous-function"},{"type":"function","title":"Halt Example - Extep.run/2","doc":"When a function returns a halt tuple, the pipeline stops and the halt reason is stored:\n\n    iex> Extep.new(%{foo: 1})\n    ...> |> Extep.run(fn _ctx -> {:halt, {:ok, \"halt message\"}} end)\n    %Extep{status: :halted, context: %{foo: 1}, message: {:ok, \"halt message\"}}\n\nIt's useful when you want to stop the pipeline and return a specific message, like a\ncancel tuple for an Oban job, for example:\n\n    iex> Extep.new(%{foo: 1})\n    ...> |> Extep.run(fn _ctx -> {:halt, {:cancel, \"cancel message\"}} end)\n    ...> |> Extep.return(fn ctx -> {:ok, ctx.bar + 2} end)\n    {:cancel, \"cancel message\"}","ref":"Extep.html#run/2-halt-example"},{"type":"function","title":"Pipeline Behavior - Extep.run/2","doc":"- If the Extep struct already has `:halted` or `:error` status, this function does nothing\n- Only processes when the current status is `:ok`\n- The context is never modified by this function","ref":"Extep.html#run/2-pipeline-behavior"},{"type":"function","title":"Extep.run/3","doc":"Runs a mutator function that updates the context with the result under the given key.\n\nThis function executes a mutator function and stores its result in the context under the\nspecified key. Unlike `run/2`, this function is designed to modify the context by adding\nor updating values.","ref":"Extep.html#run/3"},{"type":"function","title":"Parameters - Extep.run/3","doc":"- `extep` - The current Extep struct\n- `context_key` - An atom representing the key where the result will be stored\n- `fun` - A function that takes the context and returns a result","ref":"Extep.html#run/3-parameters"},{"type":"function","title":"Function Return Values - Extep.run/3","doc":"The mutator function must return one of these values:\n\n- `{:ok, value}` - Pipeline continues, `value` is stored under `context_key`\n- `{:halt, reason}` - Pipeline stops with `:halted` status, reason stored in message\n- `{:error, reason}` - Pipeline stops with `:error` status, reason stored in message\n\n**Note**: Unlike `run/2`, this function does NOT accept plain `:ok` returns. It requires\na tuple with a value to store in the context.","ref":"Extep.html#run/3-function-return-values"},{"type":"function","title":"Error Message Labeling - Extep.run/3","doc":"When errors occur, the message is stored differently based on the function type:\n\n- **Named functions**: Error labeled with function name (e.g., `%{fetch_user: \"error\"}`)\n- **Anonymous functions**: Error labeled with the context key (e.g., `%{user: \"error\"}`)","ref":"Extep.html#run/3-error-message-labeling"},{"type":"function","title":"Examples - Extep.run/3","doc":"","ref":"Extep.html#run/3-examples"},{"type":"function","title":"Successful Context Updates - Extep.run/3","doc":"This example shows how values are stored and can be used by subsequent steps:\n\n    iex> Extep.new(%{foo: 1})\n    ...> |> Extep.run(:foo, fn ctx -> {:ok, ctx.foo + 1} end)\n    ...> |> Extep.run(:bar, fn ctx -> {:ok, ctx.foo + 2} end)\n    %Extep{status: :ok, context: %{foo: 2, bar: 4}, message: nil}\n\n**Explanation**:\n- First `run/3` updates `:foo` from 1 to 2\n- Second `run/3` adds `:bar` with value 4 (using the updated foo value: 2 + 2)\n- Both operations succeed, context now contains both updated values","ref":"Extep.html#run/3-successful-context-updates"},{"type":"function","title":"Error with Named Function - Pipeline Stops - Extep.run/3","doc":"When a named function returns an error, the pipeline stops and subsequent steps are skipped:\n\n    iex> Extep.new(%{foo: 1})\n    ...> |> Extep.run(:foo, &return_error_tuple/1)\n    ...> |> Extep.run(:bar, fn ctx -> {:ok, ctx.foo + 2} end)\n    %Extep{status: :error, context: %{foo: 1}, message: %{return_error_tuple: \"error message\"}}\n\n**Explanation**:\n- First `run/3` calls `return_error_tuple/1` which returns `{:error, \"error message\"}`\n- Pipeline status becomes `:error`, original context is preserved\n- Error message is labeled with function name (`return_error_tuple`)\n- Second `run/3` is skipped because pipeline is already in error state","ref":"Extep.html#run/3-error-with-named-function-pipeline-stops"},{"type":"function","title":"Error with Anonymous Function - Pipeline Stops - Extep.run/3","doc":"When an anonymous function returns an error, the error is labeled with the context key:\n\n    iex> Extep.new(%{foo: 1})\n    ...> |> Extep.run(:foo, fn _ctx -> {:error, \"error message\"} end)\n    ...> |> Extep.run(:bar, fn ctx -> {:ok, ctx.foo + 2} end)\n    %Extep{status: :error, context: %{foo: 1}, message: %{foo: \"error message\"}}\n\n**Explanation**:\n- First `run/3` tries to update `:foo` but returns an error\n- Pipeline status becomes `:error`, original context is preserved\n- Error message is labeled with the context key (`:foo`)\n- Second `run/3` is skipped because pipeline is already in error state","ref":"Extep.html#run/3-error-with-anonymous-function-pipeline-stops"},{"type":"function","title":"Halt with Custom Message - Pipeline Stops - Extep.run/3","doc":"When a function returns halt, the pipeline stops gracefully with the halt message:\n\n    iex> Extep.new(%{foo: 1})\n    ...> |> Extep.run(:foo, fn _ctx -> {:halt, {:ok, \"halt message\"}} end)\n    ...> |> Extep.run(:bar, fn ctx -> {:ok, ctx.foo + 2} end)\n    %Extep{status: :halted, context: %{foo: 1}, message: {:ok, \"halt message\"}}\n\n**Explanation**:\n- First `run/3` returns a halt tuple with `{:ok, \"halt message\"}`\n- Pipeline status becomes `:halted`, original context is preserved\n- Halt message can be any term (here it's `{:ok, \"halt message\"}`)\n- Second `run/3` is skipped because pipeline is already halted","ref":"Extep.html#run/3-halt-with-custom-message-pipeline-stops"},{"type":"function","title":"Pipeline Behavior - Extep.run/3","doc":"- If the Extep struct already has `:halted` or `:error` status, this function does nothing\n- Only processes when the current status is `:ok`\n- On success, the context is updated with the new value under the specified key\n- On failure or halt, the context remains unchanged\n- Context keys can be new (adding) or existing (updating)","ref":"Extep.html#run/3-pipeline-behavior"},{"type":"type","title":"Extep.status/0","doc":"","ref":"Extep.html#t:status/0"},{"type":"type","title":"Extep.t/0","doc":"","ref":"Extep.html#t:t/0"},{"type":"extras","title":"Overview","doc":"# Extep\n\n![**Extep**](https://raw.githubusercontent.com/shore-gmbh/extep/main/Extep.png)\n\n**A tiny and friendly step runner for Elixir pipelines.**\n\nExtep is a simple and dependency-free utility that helps you compose Elixir pipelines using a shared context. It's useful for building multi-step workflows that can gracefully **halt** or **error** along the way. Extep is an implementation of the Railway-oriented programming and was inspired by [Ecto.Multi](https://hexdocs.pm/ecto/Ecto.Multi.html) and [Sage](https://hexdocs.pm/sage/readme.html).","ref":"readme.html"},{"type":"extras","title":"Installation - Overview","doc":"Add `extep` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:extep, \"~> 0.1.0\"}\n  ]\nend\n```\n\nThe full documentation can be found at https://hexdocs.pm/extep.","ref":"readme.html#installation"},{"type":"extras","title":"Basic Usage - Overview","doc":"Each step is a function that either checks something or returns a value to be added to the context.\n\n```elixir\nparams = %{user_id: 1, plan: \"super-power-plus\"}\n\nExtep.new(%{params: params})\n|> Extep.run(:params, &validate_params/1)\n|> Extep.run(:user, &fetch_user/1)\n|> Extep.run(:items, &fetch_items/1)\n|> Extep.return(&create_subscription/1)\n#=> {:ok, %{id: 123, object: \"subscription\", user_id: 1, items: [%{code: \"item1\"}, %{code: \"item2\"}]}}\n\ndef validate_params(%{params: %{user_id: _id}} = ctx), do: {:ok, ctx.params}\n\ndef fetch_user(%{params: %{user_id: id}}), do: {:ok, %{id: id, name: \"Alice\"}}\n\ndef fetch_items(_ctx), do: {:ok, [%{code: \"item1\"}, %{code: \"item2\"}]}\n\ndef create_subscription(%{user: user, items: items}) do\n  {:ok, %{id: 123, object: \"subscription\", user_id: user.id, items: items}}\nend\n```","ref":"readme.html#basic-usage"},{"type":"extras","title":"API - Overview","doc":"### `Extep.new/0`\n\nCreates a new, empty Extep struct:\n\n```elixir\nExtep.new()\n#=> %Extep{status: :ok, context: %{}, message: nil}\n```\n\n### `Extep.new/1`\n\nCreates a new Extep struct with a given context map:\n\n```elixir\nExtep.new(%{foo: \"bar\"})\n#=> %Extep{status: :ok, context: %{foo: \"bar\"}, message: nil}\n```\n\n### `Extep.run/2`\n\nRuns a checker function that must return one of the following:\n\n- `:ok` continues the pipeline;\n- `{:ok, value}` continues the pipeline;\n- `{:halt, reason}` halts pipeline, stores `reason` in `:message`;\n- `{:error, reason}` errors out, stores `reason` in `:message`.\n\n```elixir\nExtep.new(%{foo: 1})\n|> Extep.run(&check_something/1)\n#=> %Extep{status: :ok, context: %{foo: 1}, message: nil}\n```\n\n### `Extep.run/3`\n\nRuns a mutator function and stores the result under the given key. It must return one of the following:\n\n- `{:ok, value}` continues the pipeline, saves `value` under the given key;\n- `{:halt, reason}` halts pipeline, stores `reason` in `:message`;\n- `{:error, reason}` errors out, stores `reason` in `:message`.\n\n```elixir\nExtep.new(%{foo: 1})\n|> Extep.run(:bar, fn ctx -> {:ok, ctx.foo + 1} end)\n#=> %Extep{status: :ok, context: %{foo: 1, bar: 2}, message: nil}\n```\n\n### `Extep.return/3`\n\nReturns a final result from the pipeline:\n\n- With a function:\n\n```elixir\nExtep.new(%{foo: 1})\n|> Extep.run(:bar, fn ctx -> {:ok, ctx.foo + 1} end)\n|> Extep.return(fn ctx -> {:ok, ctx.bar + 2} end)\n#=> {:ok, 4}\n```\n\n- With a context key:\n\n```elixir\nExtep.new(%{foo: 1})\n|> Extep.run(:bar, fn ctx -> {:ok, ctx.foo + 1} end)\n|> Extep.run(:baz, fn ctx -> {:ok, ctx.bar + 2} end)\n|> Extep.return(:bar)\n#=> {:ok, 2}\n```","ref":"readme.html#api"},{"type":"extras","title":"Error Messages - Overview","doc":"If a step fails or halts, Extep stores the reason in the `:message` field. For functions passed to `run/3`, the key is the same as the context key. For anonymous functions in `run/2`, the key is `:no_label`.","ref":"readme.html#error-messages"},{"type":"extras","title":"Error Labeling with label_error - Overview","doc":"By default, `Extep.return/3` returns clean error messages. You can control error formatting using the `label_error` option:\n\n```elixir\n# Default behavior - clean error messages\nExtep.new(%{foo: 1})\n|> Extep.run(:user, fn _ctx -> {:error, \"User not found\"} end)\n|> Extep.return(:foo)\n#=> {:error, \"User not found\"}\n\n# Named function return_error_tuple/1 example\nExtep.new(%{foo: 1})\n|> Extep.run(:user, &return_error_tuple/1)\n|> Extep.return(:foo, label_error: true)\n#=> {:error, %{return_error_tuple: \"error message\"}}\n\n# With label_error: true - labeled error messages\nExtep.new(%{foo: 1})\n|> Extep.run(:user, fn _ctx -> {:error, \"User not found\"} end)\n|> Extep.return(:foo, label_error: true)\n#=> {:error, %{user: \"User not found\"}}\n```\n\nLabeled errors help you identify which step caused the failure, which is useful for debugging complex pipelines.","ref":"readme.html#error-labeling-with-label_error"},{"type":"extras","title":"License - Overview","doc":"MIT © [Shore GmbH]","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [0.2.0]","ref":"changelog.html"},{"type":"extras","title":"Added - Changelog","doc":"- Added `label_error` option to `return/3` for better error debugging and identification\n- Added extensive test coverage for `label_error` functionality","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Improved `run/2` documentation with clearer explanations of:\n  - Function return values and their effects\n  - Error message labeling for named vs anonymous functions\n  - Pipeline behavior and when functions execute\n- Improved `run/3` documentation with detailed explanations of:\n  - Parameter requirements and usage\n  - Context mutation behavior\n  - Error scenarios with step-by-step breakdowns\n  - Halt scenarios and pipeline flow control\n- Enhanced `return/3` documentation with comprehensive examples covering:\n  - Successful pipeline scenarios\n  - Error handling with and without labels\n  - Halt message handling\n  - Different error labeling behaviors\n- Improved README.md API documentation with `label_error` usage examples\n\n## [0.1.0] - Previous Release","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"- Initial implementation of Extep pipeline runner\n- Core functions: `new/0`, `new/1`, `run/2`, `run/3`, `return/2`\n- Basic error handling and pipeline flow control\n- Railway-oriented programming pattern implementation","ref":"changelog.html#added-1"},{"type":"extras","title":"License","doc":"MIT License\n\nCopyright (c) [2025] [Shore GmbH]\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}